import * as Sentry from "@sentry/node";
import express from "express";
import analyticsRoute from "./routes/analytics";

const app = express();
const port = process.env.PORT || 3000;

Sentry.init({
  dsn: "https://19a8f6e661f41ed26ec9c221954594cf@sentry.fascinated.cc/3",
  integrations: [
    // enable HTTP calls tracing
    new Sentry.Integrations.Http({ tracing: true }),
    // enable Express.js middleware tracing
    new Sentry.Integrations.Express({ app }),
    new Sentry.Integrations.OnUncaughtException(),
    new Sentry.Integrations.OnUnhandledRejection(),
    new Sentry.Integrations.Mongo({
      useMongoose: true,
    }),
  ],
  // Performance Monitoring
  tracesSampleRate: 1.0,
});

// Routes
analyticsRoute(app);

// The request handler must be the first middleware on the app
app.use(Sentry.Handlers.requestHandler() as express.RequestHandler);

// TracingHandler creates a trace for every incoming request
app.use(Sentry.Handlers.tracingHandler());

// The error handler must be registered before any other error middleware and after all controllers
app.use(Sentry.Handlers.errorHandler() as express.ErrorRequestHandler);

// Optional fallthrough error handler
app.use(function onError(err: any, req: any, res: any, next: any) {
  // The error id is attached to `res.sentry` to be returned
  // and optionally displayed to the user for support.
  res.statusCode = 500;
  res.end(res.sentry + "\n");
});

app.listen(port, () => {
  console.log(`API Server is running on http://localhost:${port}`);
});
