/**
 * Parses a time string to milliseconds.
 *
 * @param time the time to parse
 * @returns the time in milliseconds
 */
export function parseTimeToMilliseconds(time: string) {
  // Regular expression to match the numeric value and unit
  const regex = /^(\d+)([smhdwMy])$/;

  const match = time.match(regex);

  if (!match) {
    throw new Error(
      "Invalid time format. Example valid formats: 1s, 5m, 2h, 3d, 1w, 2M, 1y"
    );
  }

  const value = parseInt(match[1]);
  const unit = match[2];

  switch (unit) {
    case "s":
      return value * 1000; // seconds to milliseconds
    case "m":
      return value * 60 * 1000; // minutes to milliseconds
    case "h":
      return value * 60 * 60 * 1000; // hours to milliseconds
    case "d":
      return value * 24 * 60 * 60 * 1000; // days to milliseconds
    case "w":
      return value * 7 * 24 * 60 * 60 * 1000; // weeks to milliseconds
    case "M":
      return value * 30 * 24 * 60 * 60 * 1000; // months (approximate) to milliseconds
    case "y":
      return value * 365 * 24 * 60 * 60 * 1000; // years (approximate) to milliseconds
    default:
      throw new Error("Invalid time unit. Use one of: s, m, h, d, w, M, y");
  }
}
